# Examples
We provide a few simple examples for illustration purpose for how to use `ConversationalAgent` 
and `OpenAIFunctionsAgent` with and without tools.  
However, examples are not limited here. Workflow evaluation contains more example usages of 
those agents for different purposes, such as generating advertisement by interactive with user. 
Please checkout examples under [workflow evaluation](../workflows_evaluation) for more details.